@@ -18,7 +18,7 @@
 #include <tqdatetime.h>
 
 #include "k9fifo.h"
-#include <ktempfile.h>
+#include <tdetempfile.h>
 #include <tqimage.h>
 
 
@@ -32,7 +32,7 @@ class kDecMPEG2;
 class k9SaveImage : public TQObject,TQThread
 {
 Q_OBJECT
-  TQ_OBJECT
+  
 public:
     k9SaveImage();
     ~k9SaveImage();
